@@ -1,7 +1,7 @@
 /*
- *  $Id: CgiEnvironment.cpp,v 1.8 2001/09/05 02:18:28 sbooth Exp $
+ *  $Id: CgiEnvironment.cpp,v 1.12 2002/03/06 02:46:21 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Stephen F. Booth
+ *  Copyright (C) 1996 - 2002 Stephen F. Booth
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -29,47 +29,58 @@
 #include <cctype>
 
 #ifdef WIN32
-#include <io.h>
-#include <fcntl.h>
+# include <io.h>
+# include <fcntl.h>
+# include <stdio.h>
 #endif
 
 #include "cgicc/CgiEnvironment.h"
 
 // ========== Constructor/Destructor
 
-CGICCNS CgiEnvironment::CgiEnvironment(reader_function_t stream_reader)
+CGICCNS CgiEnvironment::CgiEnvironment(CgiInput *input)
 {
   LOGLN("CgiEnvironment::CgiEnvironment")
   
-  readEnvironmentVariables();
+  // Create a local CgiInput object for us to use
+  // In the vast majority of cases, this will be used
+  // For FastCGI applications it won't but the performance hit of
+  // an empty inline constructor is negligible
+  CgiInput local_input;
+
+  if(input == 0)
+    readEnvironmentVariables(&local_input);
+  else
+    readEnvironmentVariables(input);
 
   // On Win32, use binary read to avoid CRLF conversion
 #ifdef WIN32
-  _setmode(_fileno(stdin), _O_BINARY);
+# ifdef __BORLANDC__
+    setmode(_fileno(stdin), O_BINARY);
+# else
+    _setmode(_fileno(stdin), _O_BINARY);
+# endif
 #endif
   
-  if(stringsAreEqual( getRequestMethod(), "get")) {
+  if(stringsAreEqual(getRequestMethod(), "get")) {
     LOGLN("GET method recognized")
   }
-  else if(stringsAreEqual( getRequestMethod(), "post")) {
+  else if(stringsAreEqual(getRequestMethod(), "post")) {
     LOGLN("POST method recognized");
           
-    STDNS auto_ptr<char> temp(new char[getContentLength()]);
+    STDNS auto_ptr<char> data(new char[getContentLength()]);
 
-    // use the appropriate reader function
-    if(stream_reader == NULL) {
-      STDNS cin.read(temp.get(), getContentLength());
-      if((unsigned long)STDNS cin.gcount() != getContentLength())
+    // If input is 0, use the default implementation of CgiInput
+    if(input == 0) {
+      if(local_input.read(data.get(),getContentLength()) != getContentLength())
 	throw STDNS runtime_error("I/O error");
     }
     else {
-      // user specified a reader function
-      if((*stream_reader)
-	 (temp.get(), getContentLength()) != getContentLength())
+      if(input->read(data.get(), getContentLength()) != getContentLength())
 	throw STDNS runtime_error("I/O error");
     }
 
-    fPostData = STDNS string(temp.get(), getContentLength());
+    fPostData = STDNS string(data.get(), getContentLength());
   }
   
   fCookies.reserve(10);
@@ -87,8 +98,8 @@ CGICCNS CgiEnvironment::parseCookies()
   STDNS string data = getCookies();
 
   if(! data.empty()) {
-    STDNS string::size_type pos 	= 0;
-    STDNS string::size_type oldPos	= 0;
+    STDNS string::size_type pos;
+    STDNS string::size_type oldPos = 0;
 
     while(true) {
       // find the ';' terminating a name=value pair
@@ -137,42 +148,42 @@ CGICCNS CgiEnvironment::parseCookie(const STDNS string& data)
 
 // Read in all the environment variables
 void
-CGICCNS CgiEnvironment::readEnvironmentVariables()
+CGICCNS CgiEnvironment::readEnvironmentVariables(CgiInput *input)
 {
-  fServerSoftware 	= safeGetenv("SERVER_SOFTWARE");
-  fServerName 		= safeGetenv("SERVER_NAME");
-  fGatewayInterface 	= safeGetenv("GATEWAY_INTERFACE");
-  fServerProtocol 	= safeGetenv("SERVER_PROTOCOL");
+  fServerSoftware 	= input->getenv("SERVER_SOFTWARE");
+  fServerName 		= input->getenv("SERVER_NAME");
+  fGatewayInterface 	= input->getenv("GATEWAY_INTERFACE");
+  fServerProtocol 	= input->getenv("SERVER_PROTOCOL");
 
-  STDNS string port 	= safeGetenv("SERVER_PORT");
+  STDNS string port 	= input->getenv("SERVER_PORT");
   fServerPort 		= atol(port.c_str());
 
-  fRequestMethod 	= safeGetenv("REQUEST_METHOD");
-  fPathInfo 		= safeGetenv("PATH_INFO");
-  fPathTranslated 	= safeGetenv("PATH_TRANSLATED");
-  fScriptName 		= safeGetenv("SCRIPT_NAME");
-  fQueryString 		= safeGetenv("QUERY_STRING");
-  fRemoteHost 		= safeGetenv("REMOTE_HOST");
-  fRemoteAddr 		= safeGetenv("REMOTE_ADDR");
-  fAuthType 		= safeGetenv("AUTH_TYPE");
-  fRemoteUser 		= safeGetenv("REMOTE_USER");
-  fRemoteIdent 		= safeGetenv("REMOTE_IDENT");
-  fContentType 		= safeGetenv("CONTENT_TYPE");
+  fRequestMethod 	= input->getenv("REQUEST_METHOD");
+  fPathInfo 		= input->getenv("PATH_INFO");
+  fPathTranslated 	= input->getenv("PATH_TRANSLATED");
+  fScriptName 		= input->getenv("SCRIPT_NAME");
+  fQueryString 		= input->getenv("QUERY_STRING");
+  fRemoteHost 		= input->getenv("REMOTE_HOST");
+  fRemoteAddr 		= input->getenv("REMOTE_ADDR");
+  fAuthType 		= input->getenv("AUTH_TYPE");
+  fRemoteUser 		= input->getenv("REMOTE_USER");
+  fRemoteIdent 		= input->getenv("REMOTE_IDENT");
+  fContentType 		= input->getenv("CONTENT_TYPE");
 
-  STDNS string length 	= safeGetenv("CONTENT_LENGTH");
+  STDNS string length 	= input->getenv("CONTENT_LENGTH");
   fContentLength 	= atol(length.c_str());
 
-  fAccept 		= safeGetenv("HTTP_ACCEPT");
-  fUserAgent 		= safeGetenv("HTTP_USER_AGENT");
-  fRedirectRequest 	= safeGetenv("REDIRECT_REQUEST");
-  fRedirectURL 		= safeGetenv("REDIRECT_URL");
-  fRedirectStatus 	= safeGetenv("REDIRECT_STATUS");
-  fReferrer 		= safeGetenv("HTTP_REFERER");
-  fCookie 		= safeGetenv("HTTP_COOKIE");
+  fAccept 		= input->getenv("HTTP_ACCEPT");
+  fUserAgent 		= input->getenv("HTTP_USER_AGENT");
+  fRedirectRequest 	= input->getenv("REDIRECT_REQUEST");
+  fRedirectURL 		= input->getenv("REDIRECT_URL");
+  fRedirectStatus 	= input->getenv("REDIRECT_STATUS");
+  fReferrer 		= input->getenv("HTTP_REFERER");
+  fCookie 		= input->getenv("HTTP_COOKIE");
 
 #ifdef WIN32
   // Win32 bug fix by Peter Goedtkindt
-  STDNS string https 	= safeGetenv("HTTPS");
+  STDNS string https 	= input->getenv("HTTPS");
   if(stringsAreEqual(https, "on"))
     fUsingHTTPS = true;
   else
