@@ -1,7 +1,7 @@
 /*
- *  $Id: upload.cpp,v 1.3 2001/09/03 16:14:26 sbooth Exp $
+ *  $Id: upload.cpp,v 1.5 2002/03/03 17:41:44 sbooth Exp $
  *
- *  Copyright (C) 2000, 2001 Stephen F. Booth
+ *  Copyright (C) 1996 - 2002 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 
 #include "cgicc/CgiDefs.h"
 #include "cgicc/Cgicc.h"
-#include "cgicc/HTTPHeaders.h"
+#include "cgicc/HTTPHTMLHeader.h"
 #include "cgicc/HTMLClasses.h"
 
 #if HAVE_UNAME
@@ -112,8 +112,6 @@ main(int /*argc*/,
 
     cout << title() << "GNU cgicc v" << cgi.getVersion() 
 	 << " File Upload Test Results" << title() << endl;
-    cout << meta().set("name", "author").set("content", "Stephen F. Booth") 
-	 << endl;
 
     cout << head() << endl;
     
@@ -195,10 +193,7 @@ main(int /*argc*/,
     // Information on cgicc
     cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
     cout << "GNU cgi" << span("cc").set("class","red") << " v";
-    cout << cgi.getVersion();
-    cout << " by " << a("Stephen F. Booth")
-                       .set("href", "mailto:sbooth@gnu.org") 
-	 << br() << endl;
+    cout << cgi.getVersion() << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
     cout << " on " << cgi.getCompileDate() << br() << endl;
 
@@ -266,8 +261,6 @@ main(int /*argc*/,
     cout << comment() << style() << endl;
 
     cout << title("GNU cgicc exception") << endl;
-    cout << meta().set("name", "author")
-		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
     
     cout << body() << endl;
